@@ -10,7 +10,9 @@ setMethod("rowSums2", signature(x = "xgCMatrix"),
     x <- x[rows, , drop = FALSE]
   }
   if(is.logical(cols) && length(cols) == ncol(x)){
-    set_result_names_t(dgCMatrix_rowSums2_col_select(x, na_rm = na.rm, col_selector = cols), useNames)
+    set_result_names_t(dgCMatrix_rowSums2_bool_col_select(x, na_rm = na.rm, col_selector = cols), useNames)
+  }else if(is.integer(cols) || is.numeric(cols)){
+    set_result_names_t(dgCMatrix_rowSums2_int_col_select(x, na_rm = na.rm, col_selector = cols), useNames)
   }else{
     if(! is.null(cols)){
       x <- x[, cols, drop = FALSE]
@@ -31,11 +33,14 @@ setMethod("rowMeans2", signature(x = "xgCMatrix"),
   if(! is.null(rows)){
     x <- x[rows, , drop = FALSE]
   }
-  if(! is.null(cols)){
-    x <- x[, cols, drop = FALSE]
+  if(is.logical(cols) && length(cols) == ncol(x)){
+    set_result_names_t(dgCMatrix_rowMeans2_bool_col_select(x, na_rm = na.rm, col_selector = cols), useNames)
+  }else if(is.integer(cols) || is.numeric(cols)){
+    set_result_names_t(dgCMatrix_rowMeans2_int_col_select(x, na_rm = na.rm, col_selector = cols), useNames)
+  }else{
+    # dgCMatrix_colMeans2(t(x), na_rm = na.rm)
+    set_result_names_t(dgCMatrix_rowMeans2(x, na_rm = na.rm), useNames)
   }
-  # dgCMatrix_colMeans2(t(x), na_rm = na.rm)
-  set_result_names_t(dgCMatrix_rowMeans2(x, na_rm = na.rm), useNames)
 })
 
 
